<?php

namespace Drupal\localized_config;

use Twig\Extension\ExtensionInterface;

/**
 * Extends twig functions.
 */
class LocalizedConfigTwigFunctions extends \Twig_Extension implements ExtensionInterface {

  /**
   * Localized config helper service (localized_config.helper).
   *
   * @var \Drupal\localized_config\LocalizedConfigHelper
   */
  protected $configHelper;

  /**
   * LocalizedConfigTwigFunctions constructor.
   *
   * @param \Drupal\localized_config\LocalizedConfigHelper $configHelper
   *   Expects the localized_config.helper service.
   */
  public function __construct(LocalizedConfigHelper $configHelper) {
    $this->configHelper = $configHelper;
  }

  /**
   * {@inheritdoc}
   */
  public function getName(): string {
    return 'localized_config.twig_functions';
  }

  /**
   * {@inheritdoc}
   */
  public function getFunctions(): array {
    return [
      new \Twig_SimpleFunction('localized_config', [$this, 'localizedConfig']),
    ];
  }

  /**
   * Get a localized variable from the configs.
   *
   * @param string $plugin_name
   *   The Localized Config plugin which the config belongs to.
   * @param string|null $var_name
   *   The id of the value to fetch.
   * @param string|object|null|false $language
   *   The language to get the config from.
   *
   * @return mixed|null
   *   Return either the value, or NULL if none found.
   */
  public function localizedConfig(string $plugin_name, string $var_name = NULL, string $language = NULL) {
    return $this->configHelper->getVariable($plugin_name, $var_name, $language);
  }

}
